@@ -1,7 +1,7 @@
 package Log::Any::DBI::Query;
 
-our $DATE = '2016-02-19'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-02-22'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,7 +20,11 @@ sub _precall_logger {
 
     my ($meth) = $args->{name} =~ /.+::(.+)/;
     return if $meth =~ /\Afetch.+\z/;
-    $log->tracef("SQL query (%s): {{%s}}", $meth, $margs->[1]);
+    if ($meth eq 'execute') {
+        $log->tracef("SQL query (%s): {{%s}}", $meth, [@{$margs}[1..$#{$margs}]]);
+    } else {
+        $log->tracef("SQL query (%s): {{%s}}", $meth, $margs->[1]);
+    }
 }
 
 sub _postcall_logger {
@@ -83,7 +87,7 @@ Log::Any::DBI::Query - Log DBI queries (and results)
 
 =head1 VERSION
 
-This document describes version 0.06 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-02-19.
+This document describes version 0.07 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-02-22.
 
 =head1 SYNOPSIS
 
